module.exports = defineTest({
	description: 'arrow function without braces returning a function (#1032)'
});
